From: Milan Broz <mbroz@redhat.com>

Move log size validation from mirror target to log constructor.

Removed PAGE_SIZE restriction we no longer think necessary.

Signed-off-by: Milan Broz <mbroz@redhat.com>
Signed-off-by: Alasdair G Kergon <agk@redhat.com>
---
 drivers/md/dm-log.c   |   16 ++++++++++++++--
 drivers/md/dm-raid1.c |   12 ------------
 2 files changed, 14 insertions(+), 14 deletions(-)

Index: linux-2.6.28/drivers/md/dm-log.c
===================================================================
--- linux-2.6.28.orig/drivers/md/dm-log.c	2009-01-05 18:18:18.000000000 +0000
+++ linux-2.6.28/drivers/md/dm-log.c	2009-01-05 18:18:20.000000000 +0000
@@ -360,6 +360,17 @@ static int read_header(struct log_c *log
 	return 0;
 }
 
+static int _check_region_size(struct dm_target *ti, uint32_t region_size)
+{
+	if (region_size < 2 || region_size > ti->len)
+		return 0;
+
+	if (!is_power_of_2(region_size))
+		return 0;
+
+	return 1;
+}
+
 /*----------------------------------------------------------------
  * core log constructor/destructor
  *
@@ -395,8 +406,9 @@ static int create_log_context(struct dm_
 		}
 	}
 
-	if (sscanf(argv[0], "%u", &region_size) != 1) {
-		DMWARN("invalid region size string");
+	if (sscanf(argv[0], "%u", &region_size) != 1 ||
+	    !_check_region_size(ti, region_size)) {
+		DMWARN("invalid region size %s", argv[0]);
 		return -EINVAL;
 	}
 
Index: linux-2.6.28/drivers/md/dm-raid1.c
===================================================================
--- linux-2.6.28.orig/drivers/md/dm-raid1.c	2009-01-05 18:18:16.000000000 +0000
+++ linux-2.6.28/drivers/md/dm-raid1.c	2009-01-05 18:18:20.000000000 +0000
@@ -808,12 +808,6 @@ static void free_context(struct mirror_s
 	kfree(ms);
 }
 
-static inline int _check_region_size(struct dm_target *ti, uint32_t size)
-{
-	return !(size % (PAGE_SIZE >> 9) || !is_power_of_2(size) ||
-		 size > ti->len);
-}
-
 static int get_mirror(struct mirror_set *ms, struct dm_target *ti,
 		      unsigned int mirror, char **argv)
 {
@@ -872,12 +866,6 @@ static struct dm_dirty_log *create_dirty
 		return NULL;
 	}
 
-	if (!_check_region_size(ti, dl->type->get_region_size(dl))) {
-		ti->error = "Invalid region size";
-		dm_dirty_log_destroy(dl);
-		return NULL;
-	}
-
 	return dl;
 }
 
